PigeonOptions class
Options used when configuring Pigeon.
Constructors
- PigeonOptions({String? input, String? dartOut, @Deprecated('Mock/fake the generated Dart API instead.') String? dartTestOut, String? objcHeaderOut, String? objcSourceOut, ObjcOptions? objcOptions, String? javaOut, JavaOptions? javaOptions, String? swiftOut, SwiftOptions? swiftOptions, String? kotlinOut, KotlinOptions? kotlinOptions, String? cppHeaderOut, String? cppSourceOut, CppOptions? cppOptions, String? gobjectHeaderOut, String? gobjectSourceOut, GObjectOptions? gobjectOptions, DartOptions? dartOptions, String? copyrightHeader, String? astOut, bool? debugGenerators, String? basePath, String? dartPackageName, bool ignoreLints = true})
-
Creates a instance of PigeonOptions
const
Properties
- astOut → String?
-
Path to AST debugging output.
final
- basePath → String?
-
A base path to be prepended to all provided output paths.
final
- copyrightHeader → String?
-
Path to a copyright header that will get prepended to generated code.
final
- cppHeaderOut → String?
-
Path to the ".h" C++ file that will be generated.
final
- cppOptions → CppOptions?
-
Options that control how C++ will be generated.
final
- cppSourceOut → String?
-
Path to the ".cpp" C++ file that will be generated.
final
- dartOptions → DartOptions?
-
Options that control how Dart will be generated.
final
- dartOut → String?
-
Path to the Dart file that will be generated.
final
- dartTestOut → String?
-
Path to the Dart file that will be generated for test support classes.
final
- debugGenerators → bool?
-
True means print out line number of generators in comments at newlines.
final
- gobjectHeaderOut → String?
-
Path to the ".h" GObject file that will be generated.
final
- gobjectOptions → GObjectOptions?
-
Options that control how GObject source will be generated.
final
- gobjectSourceOut → String?
-
Path to the ".cc" GObject file that will be generated.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- ignoreLints → bool
-
Whether to ignore lint violations in generated Dart code.
final
- input → String?
-
Path to the file which will be processed.
final
- javaOptions → JavaOptions?
-
Options that control how Java will be generated.
final
- javaOut → String?
-
Path to the java file that will be generated.
final
- kotlinOptions → KotlinOptions?
-
Options that control how Kotlin will be generated.
final
- kotlinOut → String?
-
Path to the kotlin file that will be generated.
final
- objcHeaderOut → String?
-
Path to the ".h" Objective-C file will be generated.
final
- objcOptions → ObjcOptions?
-
Options that control how Objective-C will be generated.
final
- objcSourceOut → String?
-
Path to the ".m" Objective-C file will be generated.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- swiftOptions → SwiftOptions?
-
Options that control how Swift will be generated.
final
- swiftOut → String?
-
Path to the swift file that will be generated.
final
Methods
-
getPackageName(
) → String -
Returns provided or deduced package name, throws
Exceptionif none found. -
merge(
PigeonOptions options) → PigeonOptions -
Overrides any non-null parameters from
optionsinto this to make a new PigeonOptions. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, Object> -
Converts a PigeonOptions to a Map representation where:
x = PigeonOptions.fromMap(x.toMap()). -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromMap(
Map< String, Object> map) → PigeonOptions -
Creates a PigeonOptions from a Map representation where:
x = PigeonOptions.fromMap(x.toMap()).