SwiftEventChannelOptions class
Options for Swift implementation of Event Channels.
Constructors
- SwiftEventChannelOptions({})
-
Constructs a SwiftEventChannelOptions.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
Whether to include the error class in generation.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited